=========
mcot.core
=========


.. image:: https://img.shields.io/pypi/v/mcot.core.svg
        :target: https://pypi.python.org/pypi/mcot.core

.. image:: https://readthedocs.org/projects/mcotcore/badge/?version=latest
        :target: https://mcotcore.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


core utilities to run most of my code


* Free software: MIT license
* Documentation: https://mcotcore.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with `Cookiecutter
<https://github.com/audreyr/cookiecutter>`_ and the `cookiecutter-namespace-template
<https://github.com/veit/cookiecutter-namespace-template>`_ project template.

